********
Networks
********

.. default-role:: obj

.. autofunction:: nengo_extras.networks.MatrixMult

.. autofunction:: nengo_extras.networks.Product

Utilities
=========

.. autofunction:: nengo_extras.probe.probe_all
